@@ -549,8 +549,9 @@ class SnowflakeSourceConnector(C8Connector):
         If invalid, throw an exception with the cause.
         """
         config = self.get_config(integration)
+        snowflake_conn = SnowflakeConnection(config)
         try:
-            do_discover(config)
+            do_discover(snowflake_conn, config)
         except Exception as e:
             raise e
 
